==> haskell-xss-sanitize-0.3.6-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.6
id: xss-sanitize-0.3.6-AxssLeb2KY6FiVJroRfEfi
key: xss-sanitize-0.3.6-AxssLeb2KY6FiVJroRfEfi
license: BSD-2-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
abi: 334a7968236958fdf24b56c2c470c35b
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs: /usr/lib/ghc-8.6.4/site-local/xss-sanitize-0.3.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/xss-sanitize-0.3.6
hs-libraries: HSxss-sanitize-0.3.6-AxssLeb2KY6FiVJroRfEfi
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    containers-0.6.0.1 css-text-0.1.3.0-FtILrrgcRiHGI3fvImjHJI
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    tagsoup-0.14.7-8jQ2M3XvdSaFmtlOslDJPe text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.6-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.6
id: xss-sanitize-0.3.6-XSx1NcTb5oIJHz1UgYacS
key: xss-sanitize-0.3.6-XSx1NcTb5oIJHz1UgYacS
license: BSD-2-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
abi: 643b8dd213266fe647e72bf1a6d6e4bf
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs: /usr/lib/ghc-8.6.4/site-local/xss-sanitize-0.3.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/xss-sanitize-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/xss-sanitize-0.3.6
hs-libraries: HSxss-sanitize-0.3.6-XSx1NcTb5oIJHz1UgYacS
depends:
    attoparsec-0.13.2.2-EiCOeTjO227AS8aig3dZEf base-4.12.0.0
    containers-0.6.0.1 css-text-0.1.3.0-FlSDJSAS4TD5GNqLGo3XWB
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    tagsoup-0.14.7-8jQ2M3XvdSaFmtlOslDJPe text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
